#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for tests for the similarity matrix writer.

@author: mark
"""

import logging
import unittest
import os
import numpy as np
import solventmapcreator.io.similaritymatrixwriter as similaritymatrixwriter

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class SimilarityMatrixWriterTestCase(unittest.TestCase):
    """Test case for the similarity matrix writer.
    """
    def setUp(self):
        """Set up for tests.
        """
        self.expected_filename = "resources/similarity_matrix_file.csv"
        self.input_dict = {"labels":["poly_fit", "poly_fit2", "poly_fit3"],
                         "value_matrix":np.array([[0.0, 1.0, 4.0],
                                                  [1.0, 0.0, 3.0],
                                                  [4.0, 3.0, 0.0]])}
    def tearDown(self):
        """Clean up after tests.
        """
        del self.input_dict
        del self.expected_filename
        if os.path.isfile("actual_similarity_matrix_file.csv"):
            os.remove("actual_similarity_matrix_file.csv")
    def test_write_similarity_matrix_file(self):
        """Test to see if expected file is written out as expected.
        """
        actual_filename = "actual_similarity_matrix_file.csv"
        simil_mat_out = similaritymatrixwriter.write_similarity_matrix_file(actual_filename, self.input_dict)
        self.assertEqual(0, simil_mat_out)
        with open(self.expected_filename, 'r') as exp_file:
            exp_file_lines = exp_file.readlines()
            with open(actual_filename, 'r') as act_file:
                act_file_lines = act_file.readlines()
                self.assertListEqual(act_file_lines, exp_file_lines)
    def test_create_file_line(self):
        """Test to see if expected line is produced.
        """
        expected_line = ['poly_fit', '0.0000000', '1.0000000', '4.0000000']
        actual_line  = similaritymatrixwriter.create_file_line("poly_fit", self.input_dict["value_matrix"][0])
        self.assertListEqual(expected_line, actual_line)
